==> siddhi-query-api-5.0.0-sources.jar: io/siddhi/query/api/definition/TableDefinition.java <==
/*
 * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package io.siddhi.query.api.definition;

import io.siddhi.query.api.annotation.Annotation;

/**
 * Siddhi Table Definition.
 */
public class TableDefinition extends AbstractDefinition {
    private static final long serialVersionUID = 1L;

    protected TableDefinition(String id) {
        super(id);
    }

    public static TableDefinition id(String id) {
        return new TableDefinition(id);
    }

    public TableDefinition attribute(String attributeName, Attribute.Type type) {
        checkAttribute(attributeName);
        this.attributeList.add(new Attribute(attributeName, type));
        return this;
    }

    public TableDefinition annotation(Annotation annotation) {
        annotations.add(annotation);
        return this;
    }

    @Override
    public String toString() {
        return super.toString("table");
    }

}

==> siddhi-query-api-5.1.0-sources.jar: io/siddhi/query/api/definition/TableDefinition.java <==
/*
 * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package io.siddhi.query.api.definition;

import io.siddhi.query.api.annotation.Annotation;

/**
 * Siddhi Table Definition.
 */
public class TableDefinition extends AbstractDefinition {
    private static final long serialVersionUID = 1L;
    protected String[] attributeNameArray;
    protected boolean hasDefinitionChanged = false;
    
    protected TableDefinition(String id) {
        super(id);
    }

    public static TableDefinition id(String id) {
        return new TableDefinition(id);
    }

    public TableDefinition attribute(String attributeName, Attribute.Type type) {
        checkAttribute(attributeName);
        this.attributeList.add(new Attribute(attributeName, type));
        this.hasDefinitionChanged = true;
        return this;
    }

    public TableDefinition annotation(Annotation annotation) {
        annotations.add(annotation);
        return this;
    }

    @Override
    public String[] getAttributeNameArray() {
        if (hasDefinitionChanged) {
            int attributeListSize = attributeList.size();
            this.attributeNameArray = new String[attributeListSize];
            for (int i = 0; i < attributeListSize; i++) {
                this.attributeNameArray[i] = attributeList.get(i).getName();
            }

            hasDefinitionChanged = false;
        }

        return this.attributeNameArray;
    }

    @Override
    public String toString() {
        return super.toString("table");
    }

}
